/** @file
 * Copyright(C) OASIS(R) 2007,2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.
 *
 * This file contains definitions used in the SCA API.
 * @author SCA-C-C++ TC
 * @version 1.1
 * @date 4 March 2010
 */

/**
 * Opaque token for identifying a Service or Reference instance.
 */
typedef void *SCAREF;

/* Completion Codes */
/**
 * Successful completion code.
 */
#define SCACC_OK             0
/**
 * Function completed successfully, but there is more data to retrieve.
 */
#define SCACC_WARNING        1
/**
 * Unuccessful completion code. See reason code for details.
 */
#define SCACC_FAULT          2
/**
 * Operation invocation resulted in a business fault.
 */
#define SCACC_ERROR          3

/* Reason Codes */
/**
 * Service provider is not currently avaliable.
 */
#define SCA_SERVICE_UNAVAILABLE    1
/**
 * Multiple services can be wired to a reference.
 */
#define SCA_MULTIPLE_SERVICES      2
/**
 * The buffer length is too small to receive all of the available data.
 */
#define SCA_DATA_TRUNCATED         3
/**
 * One of the paramaters has an incorrect value.
 */
#define SCA_PARAMETER_ERROR        4
/**
 * Only one outstanding long running operation is allowed on a reference or callback at one time.
 */
 #define SCA_BUSY                  5
/**
 * The SCA runtime detected an error with a component or composite definition or implementation.
 */
#define SCA_RUNTIME_ERROR          6

/* Response Types */
/**
 * The response to a long running operation has not been received yet.
 */
#define SCA_NO_RESPONSE    0
/**
 * A reply message has been received for a long running operation.
 */
#define SCA_REPLY_MESSAGE  1
/**
 * A fault message has been received for a long running operation.
 */
#define SCA_FAULT_MESSAGE  2
