/** @file
 * Copyright(C) OASIS(R) 2007,2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.
 *
 * This file contains the SCA API functions declarations for implementing components in programs.
 * @author SCA-C-C++ TC
 * @version 1.1
 * @date 4 March 2010
 */

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Determine which service was used to invoke a component implementation.
 * @param serviceName Name of the service used to invoke the component.
 * @param compCode SCACC_OK
 * @param reason Unused
 */
void SCAService(wchar_t *serviceName, int *compCode, int *reason);

/**
 * Determine which operation was used to invoke a component implementation.
 * @param operationName Name of the operation used to invoke the component.
 * @param compCode SCACC_OK
 * @param reason Unused
 */
void SCAOperation(wchar_t *operationName, int *compCode, int *reason);

/**
 * Retrieve the request message.
 * @param serviceName Name returned by SCAService().
 * @param operationName Name returned by SCAOperation().
 * @param bufferLen Input: Maximum number of bytes that can be returned.
 *                  Output: Actual number of bytes returned or size needed to hold entire message.
 * @param buffer Request message.
 * @param compCode
 *                 - SCACC_OK, if the call is successful.
 *                 - SCACC_WARNING, if the request data was truncated.
 *                                The buffer size needs to be increased and the call repeated with the
 *                                larger buffer.
 * @param reason SCA_DATA_TRUNCATED if the request data was truncated.
 */
void SCAMessageIn(wchar_t *serviceName,
                  wchar_t *operationName,
                  int *bufferLen,
                  void *buffer,
                  int *compCode,
                  int *reason);

/**
 * Return a reply message.
 * @param serviceName Name returned by SCAService().
 * @param operationName Name returned by SCAOperation().
 * @param bufferLen Length of the reply message buffer.
 * @param buffer Reply message.
 * @param compCode SCACC_OK.
 * @param reason unused.
 */
void SCAMessageOut(wchar_t *serviceName,
                   wchar_t *operationName,
                   int *bufferLen,
                   void *buffer,
                   int *compCode,
                   int *reason);

#ifdef __cplusplus
}
#endif
